@@ -1,7 +1,7 @@
 #include <kdialog.h>
 #include <klocale.h>
 
-#include "/usr/src/ports/kdewebdev/kdewebdev-15.04.3-1.i686/build/kfilereplace/kfilereplaceviewwdg.h"
+#include "/usr/src/ports/kdewebdev/kdewebdev-16.08.3-1.x86_64/build/kfilereplace/kfilereplaceviewwdg.h"
 
 #include <qvariant.h>
 /*
